==> ibiz-cloud-core-8.1.0.301-sources.jar: net/ibizsys/central/cloud/core/ServiceHubSettingBase.java <==
package net.ibizsys.central.cloud.core;

import java.util.List;

import net.ibizsys.central.cloud.core.util.domain.DataSource;
import net.ibizsys.central.cloud.core.util.domain.DeploySystem;
import net.ibizsys.runtime.util.KeyValueUtils;

public abstract class ServiceHubSettingBase implements IServiceHubSetting {

	private static final org.apache.commons.logging.Log log = org.apache.commons.logging.LogFactory.getLog(ServiceHubSettingBase.class);
	
	/**
	 * 服务网关
	 */
	public static final String PREFIX = "ibiz.servicehub";
	
	private String id = null;
	private Long node = null;
	private boolean registerNamingService = true;
	private boolean publishConfig = true;
	private boolean enableReloadSystem = true;
	private boolean enableDebug = false;
	private boolean enableServletApp = true;
	private boolean enableProxyApp = true;
	private boolean enableRTCodeMode = false;
	
	
	private List<DataSource> dataSources = null;
	private List<DeploySystem> deploySystems = null;
	private boolean enableAppGateway = false;
	private String tempFolder = null;
	private String fileFolder = null;
	private String fontFolder = null;
	private String reportFolder = null;
	private String debuggerCmd = null;
	private boolean startDebugger = false;
	private String cloudPluginServiceId = null;

	private int workThreadCorePoolSize = 20;
	private int workThreadMaximumPoolSize = 40;
	private int workThreadBlockingQueueSize = 2000;
	
	
	@Override
	public String getId() {
		return this.id;
	}
	
	public void setId(String id) {
		this.id = id;
	}
	
	public Long getNode() {
		return this.node;
	}
	
	public void setNode(Long node) {
		this.node = node;
		if(node != null && node != 0) {
			KeyValueUtils.setWorkerId(node);
		}
	}
	
	@Override
	public boolean isRegisterNamingService() {
		return this.registerNamingService;
	}
	
	public void setRegisterNamingService(boolean registerNamingService) {
		this.registerNamingService = registerNamingService;
	}
	
	
	@Override
	public boolean isPublishConfig() {
		return this.publishConfig;
	}
	
	public void setPublishConfig(boolean publishConfig) {
		this.publishConfig = publishConfig;
	}
	
	@Override
	public boolean isEnableReloadSystem() {
		return enableReloadSystem;
	}

	public void setEnableReloadSystem(boolean enableReloadSystem) {
		this.enableReloadSystem = enableReloadSystem;
	}

	@Override
	public List<DataSource> getDataSources() {
		return this.dataSources;
	}
	
	public void setDataSources(List<DataSource> dataSources) {
		this.dataSources = dataSources;
	}
	
	
	@Override
	public boolean isEnableServletApp() {
		return this.enableServletApp;
	}
	
	
	public void setEnableServletApp(boolean enableServletApp) {
		this.enableServletApp = enableServletApp;
	}

	@Override
	public boolean isEnableProxyApp() {
		return this.enableProxyApp;
	}
	
	public void setEnableProxyApp(boolean enableProxyApp) {
		this.enableProxyApp = enableProxyApp;
	}

	@Override
	public boolean isEnableDebug() {
		return this.enableDebug;
	}
	
	public void setEnableDebug(boolean enableDebug) {
		this.enableDebug = enableDebug;
	}
	

	@Override
	public List<DeploySystem> getDeploySystems() {
		return this.deploySystems;
	}
	
	public void setDeploySystems(List<DeploySystem> deploySystems) {
		this.deploySystems = deploySystems;
	}

	@Override
	public boolean isEnableAppGateway() {
		return enableAppGateway;
	}

	public void setEnableAppGateway(boolean enableAppGateway) {
		this.enableAppGateway = enableAppGateway;
	}

	@Override
	public String getTempFolder() {
		return tempFolder;
	}

	public void setTempFolder(String tempFolder) {
		this.tempFolder = tempFolder;
	}

	@Override
	public String getFileFolder() {
		return fileFolder;
	}

	public void setFileFolder(String fileFolder) {
		this.fileFolder = fileFolder;
	}

	@Override
	public String getFontFolder() {
		return fontFolder;
	}

	public void setFontFolder(String fontFolder) {
		this.fontFolder = fontFolder;
	}
	
	@Override
	public String getReportFolder() {
		return reportFolder;
	}

	public void setReportFolder(String reportFolder) {
		this.reportFolder = reportFolder;
	}

	@Override
	public String getDebuggerCmd() {
		return this.debuggerCmd;
	}
	
	public void setDebuggerCmd(String debuggerCmd) {
		this.debuggerCmd = debuggerCmd;
	}

	@Override
	public boolean isStartDebugger() {
		return startDebugger;
	}

	public void setStartDebugger(boolean startDebugger) {
		this.startDebugger = startDebugger;
	}

	@Override
	public String getCloudPluginServiceId() {
		return this.cloudPluginServiceId;
	}
	
	public void setCloudPluginServiceId(String cloudPluginServiceId) {
		this.cloudPluginServiceId = cloudPluginServiceId;
	}

	
	@Override
	public boolean isEnableRTCodeMode() {
		return enableRTCodeMode;
	}

	public void setEnableRTCodeMode(boolean enableRTCodeMode) {
		this.enableRTCodeMode = enableRTCodeMode;
	}

	@Override
	public void loadConfig() {
		// TODO Auto-generated method stub
		
	}

	@Override
	public int getWorkThreadCorePoolSize() {
		return this.workThreadCorePoolSize;
	}
	
	public void setWorkThreadCorePoolSize(int workThreadCorePoolSize) {
		this.workThreadCorePoolSize = workThreadCorePoolSize;
	}

	@Override
	public int getWorkThreadMaximumPoolSize() {
		return this.workThreadMaximumPoolSize;
	}

	public void setWorkThreadMaximumPoolSize(int workThreadMaximumPoolSize) {
		this.workThreadMaximumPoolSize = workThreadMaximumPoolSize;
	}
	
	@Override
	public int getWorkThreadBlockingQueueSize() {
		return this.workThreadBlockingQueueSize;
	}
	
	public void setWorkThreadBlockingQueueSize(int workThreadBlockingQueueSize) {
		this.workThreadBlockingQueueSize = workThreadBlockingQueueSize;
	}
	
	
	
	
}

==> ibiz-cloud-core-8.1.0.310-sources.jar: net/ibizsys/central/cloud/core/ServiceHubSettingBase.java <==
package net.ibizsys.central.cloud.core;

import java.util.List;

import net.ibizsys.central.cloud.core.util.domain.DataSource;
import net.ibizsys.central.cloud.core.util.domain.DeploySystem;
import net.ibizsys.runtime.util.KeyValueUtils;

public abstract class ServiceHubSettingBase implements IServiceHubSetting {

	private static final org.apache.commons.logging.Log log = org.apache.commons.logging.LogFactory.getLog(ServiceHubSettingBase.class);
	
	/**
	 * 服务网关
	 */
	public static final String PREFIX = "ibiz.servicehub";
	
	private String id = null;
	private Long node = null;
	private boolean registerNamingService = true;
	private boolean publishConfig = true;
	private boolean enableReloadSystem = true;
	private boolean enableDebug = false;
	private boolean enableServletApp = true;
	private boolean enableProxyApp = true;
	private boolean enableRTCodeMode = false;
	private boolean enableProdMode = false;
	
	
	private List<DataSource> dataSources = null;
	private List<DeploySystem> deploySystems = null;
	private boolean enableAppGateway = false;
	private String tempFolder = null;
	private String fileFolder = null;
	private String fontFolder = null;
	private String reportFolder = null;
	private String debuggerCmd = null;
	private boolean startDebugger = false;
	private String cloudPluginServiceId = null;

	private int workThreadCorePoolSize = 20;
	private int workThreadMaximumPoolSize = 40;
	private int workThreadBlockingQueueSize = 2000;
	
	
	@Override
	public String getId() {
		return this.id;
	}
	
	public void setId(String id) {
		this.id = id;
	}
	
	public Long getNode() {
		return this.node;
	}
	
	public void setNode(Long node) {
		this.node = node;
		if(node != null && node != 0) {
			KeyValueUtils.setWorkerId(node);
		}
	}
	
	@Override
	public boolean isRegisterNamingService() {
		return this.registerNamingService;
	}
	
	public void setRegisterNamingService(boolean registerNamingService) {
		this.registerNamingService = registerNamingService;
	}
	
	
	@Override
	public boolean isPublishConfig() {
		return this.publishConfig;
	}
	
	public void setPublishConfig(boolean publishConfig) {
		this.publishConfig = publishConfig;
	}
	
	@Override
	public boolean isEnableReloadSystem() {
		return enableReloadSystem;
	}

	public void setEnableReloadSystem(boolean enableReloadSystem) {
		this.enableReloadSystem = enableReloadSystem;
	}

	@Override
	public List<DataSource> getDataSources() {
		return this.dataSources;
	}
	
	public void setDataSources(List<DataSource> dataSources) {
		this.dataSources = dataSources;
	}
	
	
	@Override
	public boolean isEnableServletApp() {
		return this.enableServletApp;
	}
	
	
	public void setEnableServletApp(boolean enableServletApp) {
		this.enableServletApp = enableServletApp;
	}

	@Override
	public boolean isEnableProxyApp() {
		return this.enableProxyApp;
	}
	
	public void setEnableProxyApp(boolean enableProxyApp) {
		this.enableProxyApp = enableProxyApp;
	}

	@Override
	public boolean isEnableDebug() {
		return this.enableDebug;
	}
	
	public void setEnableDebug(boolean enableDebug) {
		this.enableDebug = enableDebug;
	}
	

	@Override
	public List<DeploySystem> getDeploySystems() {
		return this.deploySystems;
	}
	
	public void setDeploySystems(List<DeploySystem> deploySystems) {
		this.deploySystems = deploySystems;
	}

	@Override
	public boolean isEnableAppGateway() {
		return enableAppGateway;
	}

	public void setEnableAppGateway(boolean enableAppGateway) {
		this.enableAppGateway = enableAppGateway;
	}

	@Override
	public String getTempFolder() {
		return tempFolder;
	}

	public void setTempFolder(String tempFolder) {
		this.tempFolder = tempFolder;
	}

	@Override
	public String getFileFolder() {
		return fileFolder;
	}

	public void setFileFolder(String fileFolder) {
		this.fileFolder = fileFolder;
	}

	@Override
	public String getFontFolder() {
		return fontFolder;
	}

	public void setFontFolder(String fontFolder) {
		this.fontFolder = fontFolder;
	}
	
	@Override
	public String getReportFolder() {
		return reportFolder;
	}

	public void setReportFolder(String reportFolder) {
		this.reportFolder = reportFolder;
	}

	@Override
	public String getDebuggerCmd() {
		return this.debuggerCmd;
	}
	
	public void setDebuggerCmd(String debuggerCmd) {
		this.debuggerCmd = debuggerCmd;
	}

	@Override
	public boolean isStartDebugger() {
		return startDebugger;
	}

	public void setStartDebugger(boolean startDebugger) {
		this.startDebugger = startDebugger;
	}

	@Override
	public String getCloudPluginServiceId() {
		return this.cloudPluginServiceId;
	}
	
	public void setCloudPluginServiceId(String cloudPluginServiceId) {
		this.cloudPluginServiceId = cloudPluginServiceId;
	}

	
	@Override
	public boolean isEnableRTCodeMode() {
		return enableRTCodeMode;
	}

	public void setEnableRTCodeMode(boolean enableRTCodeMode) {
		this.enableRTCodeMode = enableRTCodeMode;
	}

	@Override
	public void loadConfig() {
		// TODO Auto-generated method stub
		
	}

	@Override
	public int getWorkThreadCorePoolSize() {
		return this.workThreadCorePoolSize;
	}
	
	public void setWorkThreadCorePoolSize(int workThreadCorePoolSize) {
		this.workThreadCorePoolSize = workThreadCorePoolSize;
	}

	@Override
	public int getWorkThreadMaximumPoolSize() {
		return this.workThreadMaximumPoolSize;
	}

	public void setWorkThreadMaximumPoolSize(int workThreadMaximumPoolSize) {
		this.workThreadMaximumPoolSize = workThreadMaximumPoolSize;
	}
	
	@Override
	public int getWorkThreadBlockingQueueSize() {
		return this.workThreadBlockingQueueSize;
	}
	
	public void setWorkThreadBlockingQueueSize(int workThreadBlockingQueueSize) {
		this.workThreadBlockingQueueSize = workThreadBlockingQueueSize;
	}

	@Override
	public boolean isEnableProdMode() {
		return enableProdMode;
	}

	public void setEnableProdMode(boolean enableProdMode) {
		this.enableProdMode = enableProdMode;
	}
	
	
	
	
}
